@@ -20,6 +20,7 @@
 
 # Dependencies
 import os
+import sys
 import argparse
 
 try:
@@ -31,7 +32,7 @@ except ImportError:
 # The Onionprobe version string
 # Uses Semantic Versioning 2.0.0
 # See https://semver.org
-onionprobe_version = '1.4.0'
+onionprobe_version = '1.4.1'
 
 # The base path for this project
 basepath = os.path.join(os.path.dirname(os.path.abspath(__file__)), os.pardir, os.pardir) + os.sep
@@ -277,7 +278,14 @@ def cmdline_parser():
             parser.add_argument('-e', '--endpoints', nargs='*', help='Add endpoints to the test list', metavar="ONION-ADDRESS1")
 
         else:
-            config[argument]['type'] = type(config[argument]['default'])
+            # Handle the type argument
+            if isinstance(config[argument]['default'], bool):
+                # Type argument became deprecated on Python 3.12, and was removed on Python 3.14
+                # Details at https://gitlab.torproject.org/tpo/onion-services/onionprobe/-/issues/116
+                if sys.version_info < (3, 12):
+                    config[argument]['type'] = type(config[argument]['default'])
+            else:
+                config[argument]['type'] = type(config[argument]['default'])
 
             if not isinstance(config[argument]['default'], bool) and config[argument]['default'] != '':
                 config[argument]['help'] += ' (default: %(default)s)'
